capture log close
log using mco18-test-fit-svy-2018-03-09, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Complex samples - survey estimation

local pgm mco18-test-fit-svy-2018-03-09
local dte 2018-04-04
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

// #1 load data

use svyhrs4, clear

local rhsvars "age female ed11less ed12 ed1315 ed16plus"
codebook arthritis `rhsvars' secu kwgtr stratum, compact

// #2 declare the survey design

svyset secu             /// clusters
    [pweight=kwgtr],    /// weights
    strata(stratum)     /// stratum
    vce(linearized) singleunit(missing) // method to compute SEs

// #3 check the svy variables

tab1 secu, miss
tab1 stratum, miss
return list
sum kwgtr stratum

* plots of weight and stratum

local graphname "kwgtr-weight-dotplot"
dotplot kwgtr, caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.png, replace width(750)

local graphname "stratum-dotplot"
dotplot stratum, caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.png, replace width(750)

// #4 examine age with and without weights

local graphname "age-dotplot"
dotplot age, ylabel(25(10)105) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.png, replace width(750)

sum age // without svy adjustments
qui svy: mean age // compute svy mean
estat sd // retrieve svy sd

// #5 descriptive statisics with and without weights

sum arthritis // without svy adjustment
svy: mean arthritis // compute svy mean
estat sd // retrieve svy sd

sum age
svy: mean age
estat sd

sum female
svy: mean female
estat sd

sum ed11less
svy: mean ed11less
estat sd

sum ed12
svy: mean ed12
estat sd

sum ed1315
svy: mean ed1315
estat sd

sum ed16plus
svy: mean ed16plus
estat sd

// #6 logits without survey

logit arthritis age i.female ed11less ed1315 ed16plus
estimates store nosvy // store estimates
test age
predict nosvyphat
label var nosvyphat "nosvy phat"

// #7 non-svy with weights and cluster

logit arthritis age i.female ed11less ed1315 ed16plus ///
    [pweight=kwgtr], cluster(secu)
estimates store wtclstr
test age
predict wtclstrphat
label var wtclstrphat "wtclstr phat"

// #8 logits with survey

svy: logit arthritis age i.female ed11less ed1315 ed16plus
estimates store svy
test age
predict svyphat
label var svyphat "svy phat"

// #9 tables of estimated coefficients

estimates table nosvy wtclstr svy, b(%9.3f) t(%9.2f) stats(N) eform

// #10 comparing predictions

pwcorr nosvyphat wtclstrphat svyphat

local agerng "(25(2.5)105)"
local cntrlvars "female=1 ed11less=0 ed1315=0 ed16plus=0"

estimates restore svy
mgen, at(age=`agerng' `cntrlvars') atmeans stub(svyPr)

estimates restore wtclstr
mgen, at(age=`agerng' `cntrlvars') atmeans stub(wtclPr)

estimates restore nosvy
mgen, at(age=`agerng' `cntrlvars') atmeans stub(nosvyPr)

local nosvyline     "msym(i) mcol(red)   lcol(black) lpat(solid)"
local wtclline      "msym(i) mcol(red)   lcol(red)   lpat(dash)"
local svyline       "msym(i) mcol(green) lcol(green) lpat(shortdash)"
local title         "Women with a high school degrees"
label var nosvyPrpr "Non-survey estimates"
label var wtclPrpr  "Weight and cluster estimates"
label var svyPrpr   "Survey estimates"
local ylab          "0(.1)1"
local yline01       "yline(0 1, lcol(gs13))"
local ytitle        "Pr( Arthritis | x,age )"
local xlab          "25(10)105"

local graphname "predXage"
graph twoway ///
    (connected nosvyPrpr nosvyPrage, `nosvyline') ///
    (connected wtclPrpr nosvyPrage, `wtclline') ///
    (connected svyPrpr nosvyPrage, `svyline'), ///
    title("`title'") xtitle("Age") ytitle("`ytitle'") ///
    xlabel(`xlab') ylabel(`ylab', grid) `yline01' ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.png, replace width(750)

log close
exit
