capture log close
log using mco18-cme-outcomes-crm-2018-04-10, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
// CME: Comparing Marginal Effects Across Models
// Variable choice: Comparing effects on different outcomes

local pgm mco18-cme-outcomes-crm-2018-04-10
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  ===============================================================
//  #1 Data management

use gss7216, clear

local vars mntlhlth physhlth woman married age faminc ///
           race college parent reltrad

foreach var in `vars' {
    drop if `var' >= .
}

sum mntlhlth physhlth i.woman i.married age faminc ///
                  i.race i.college i.parent i.year
codebook `vars', compact

//  ===============================================================
//  #2 Simultaneous Estimation with GSEM
 
//  Note: vce(robust) required when same observations across models

gsem (mntlhlth <- i.woman i.married c.age faminc ///
                  i.race i.college i.parent i.year, nbreg) ///
     (physhlth <- i.woman i.married c.age faminc ///
                  i.race i.college i.parent i.year, nbreg), ///
     vce(robust)
        
est store gsemmodel

//  ===============================================================
//  #2 Compute and compare marginal effects

//  ===============================================================
//  #2a Effects for binary regressors

mlincom, clear
foreach var in woman married college parent {
    est restore gsemmodel
    margins, dydx(`var') post        
    qui mlincom 1,   rowname(`var':MentHlth) stat(est se p) add
    qui mlincom 2,   rowname(`var':PhysHlth) stat(est se p) add
    qui mlincom 1-2, rowname(`var':Difference) stat(est se p) add
}
    
//  ===============================================================
//  #2b Effect of continuous regressors + SD

foreach var in age faminc {
    est restore gsemmodel
    qui sum `var'
    margins, at(`var'=gen(`var')) at(`var'=gen(`var' + `r(sd)')) post    
    qui mlincom 2-1, rowname(`var':MentHlth) stat(est se p) add
    qui mlincom 4-3, rowname(`var':PhysHlth) stat(est se p) add
    qui mlincom (2-1)-(4-3), rowname(`var':Difference) stat(est se p) add 
}

//  ===============================================================
//  #2c Effects for multicategory regressors

est restore gsemmodel
margins i.race, post 

qui {
    mlincom 2-1, rowname(blackVwhite:MentHlth) stat(est se p) add
    mlincom 5-4, rowname(blackVwhite:PhysHlth) stat(est se p) add
    mlincom (2-1)-(5-4), rowname(blackVwhite:Difference) stat(est se p) add

    mlincom 3-1, rowname(otherVwhite:MentHlth) stat(est se p) add
    mlincom 6-4, rowname(otherVwhite:PhysHlth) stat(est se p) add
    mlincom (3-1)-(6-4), rowname(otherVwhite:Difference) stat(est se p) add

    mlincom 3-2, rowname(otherVblack:MentHlth) stat(est se p) add
    mlincom 6-5, rowname(otherVblack:PhysHlth) stat(est se p) add
    mlincom (3-2)-(6-5), rowname(otherVblack:Difference) stat(est se p) add
}

mlincom, twidth(20) ///
    title(AMEs for mental and physical health and cross model differences)    

est restore gsemmodel

log close
exit

