capture log close
log using mco18-groups-diabetes-2018-03-29, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

local pgm mco18-groups-diabetes-2018-03-29 // used to name graphs

//  Comparing Gropus in Binary Regression Models Using Predictions
//  Scott Long and Sarah Mustillo / 2018-01-30
//
//  Logit for diabetes
//
//  To obtain the data for these analyses
//
//    1) Type -search groupsbrm- and install the package
//    2) Type -help groupsbrm- for information about downloading the data
//
//  This do-files uses SPost13 by Scott Long and Jeremy Freese. To install
//  this package, type -search spost13_ado- and follow instructions.
//  You must also install gologit2 and oglm: search gologit2 and
//  search oglm. You must install the most current versions.

//  #1 Global macros used in analyses

//  Specify regressors in models

global rhsvars female highschool /// variables
    married ihsincome age active obese
global rhsvarsfs i.female i.highschool /// factor syntax
    i.married c.ihsincome c.age##c.age##i.active i.obese
global rhsfull /// fully interactive model
    ibn.white ibn.white#($rhsvarsfs)

//  Options for graphs such a colors and line sizes.

* graph PR by race
global LINwht clcol(blue) lpat(solid) lwid(*1.2) ///
            msym(i)
global SYMwht msym(S) mcol(blue) msiz(*0.9)

global LINnon clcol(black) lpat(solid) lwid(*1.2) ///
            msym(i)
global SYMnon msym(O) mcol(black) msiz(*1.1)

* graph DCrace
global LINdc  clcol(black*1) lpat(solid) lwid(*1.2) ///
              msym(i)
global LINci  msym(i i) clwid(*.7 *.7) clcol(black*.5 black*.5) ///
              clpat(dash dash)
global SYMdc  msym(T) mcol(black) msiz(*.9)

* graph PR by race and activity
global LINwhtI msym(i) clcol(blue) lpat(solid) lwid(*1.2) // WHTinactive
global SYMwhtI msym(Sh) mcol(blue)  msiz(*.9) mlwid(*1.2)

global LINwhtA msym(i)  clcol(blue) lpat(solid) lwid(*1.2) // WHTactive
global SYMwhtA msym(S)  mcol(blue)  msiz(*.9)

global LINnonI msym(i)  clcol(black) lpat(solid) lwid(*1.2) // NONinactive
global SYMnonI msym(Oh) mcol(black) msiz(*1.1) mlwid(*1.2)

global LINnonA msym(i)  clcol(black) lpat(solid) lwid(*1.2) // NONactive
global SYMnonA msym(O)  mcol(black) msiz(*1.1)

global LINdca msym(i) clcol(black) lpat(solid) lwid(*1.2) // active sig
global SYMdca msym(D) mcol(black) msiz(*.9)

global LINdcans msym(i) clcol(black) lpat(shortdash) lwid(*1.2) // act nonsig
global SYMdcans msym(D) mcol(black) msiz(*.9) mlwid(*1.2)

global LINdci msym(i) clcol(black) lpat(solid) lwid(*1.2) // inact sig
global SYMdci  msym(Dh) mcol(black) msiz(*.9)

global LINdcins msym(i) clcol(black) lpat(shortdash) lwid(*1.2) // inact nonsig
global SYMdcins msym(Dh) mcol(black) msiz(*.9) mlwid(*1.2)

//  #2 Setup for complex survey data
//
//  groups-hrs3.dta contains variables from the RAND Health and Retirement
//  Survey 2006 fat file h06f2b.dta and rndhrs_n.dta. To create our dataset,
//  see groups-hrs-supportV7.do. Type -help groupsbrm- for details.

//  Since HRS data have a complex survey design, -svyset- must be used.

use groups-hrs3, clear
svyset secu [pweight=kwgtr], strata(stratum) ///
      vce(linearized) singleunit(centered)

// ===========================
//  SECTION 0: descriptive statistics

//  Define a global macro with variables to be used in analyses

global descvarsnogrp goodhlth diabetes female highschool married ///
    income ihsincome age active obese

//  #2 Descriptives using svy adjustments

svy: tab white, obs // size of groups
di "N white: " 16226-3799 

//  Whites

foreach var in $descvarsnogrp {
    qui svy: mean `var' if white==1
    estat sd
    mat stats = r(mean), r(sd)
    matrix whtstats = nullmat(whtstats) \ stats
}

//  Nonwhites

foreach var in $descvarsnogrp {
    qui svy: mean `var' if white==0
    estat sd
    mat stats = r(mean), r(sd)
    matrix nonstats = nullmat(nonstats) \ stats
}

//  #3 Test if means are equal
//  -svy: reg- allows tests of difference of means with complex survey data
//  All differences are significat

foreach var in $descvarsnogrp {

    di _new "Variable: `var'" _new
    if "`var'"=="age" | "`var'"=="ihsincome"| "`var'"=="income" {
        svy: reg `var' white
    }
    else svy: tabulate white `var'
}

//  #4 summary of results

//  difference

mat stats = whtstats, nonstats, (whtstats[1...,1]-nonstats[1...,1])
mat colnames stats = whtmn sd nonmn nonsd mndif
mat rownames stats = $descvarsnogrp
matlist stats, format(%8.3f)

// ===========================
//  SECTION 1: Logit estimates

//  #1.1 Logit of diabetes
//  Table 3

svy: logit diabetes $rhsfull, nocon nolog
estimates store fullmodel

//  #1.2 Chow test of equal betas - these tests are invalid!
//  Table 3

test _b[0.white]                        = _b[1.white] // intercepts
test _b[0.white#1.female]               = _b[1.white#1.female]
test _b[0.white#1.highschool]           = _b[1.white#1.highschool]
test _b[0.white#1.married]              = _b[1.white#1.married]
test _b[0.white#c.ihsincome]            = _b[1.white#c.ihsincome]
test _b[0.white#c.age]                  = _b[1.white#c.age]
test _b[0.white#c.age#c.age]            = _b[1.white#c.age#c.age]
test (_b[0.white#c.age#c.age]           = _b[1.white#c.age#c.age]) ///
     (_b[0.white#c.age]                 = _b[1.white#c.age])
test _b[0.white#1.active]               = _b[1.white#1.active]
test _b[0.white#1.active#c.age]         = _b[1.white#1.active#c.age]
test _b[0.white#1.active#c.age#c.age]   = _b[1.white#1.active#c.age#c.age]
test _b[0.white#1.obese]                = _b[1.white#1.obese]

//  #1.4 Insample predicted probabilities

predict prdiabetes
dotplot prdiabetes, over(white) scale(1.2)
graph export `pgm'-phat.png, replace width(1200)

// ===================================
//  SECTION 2: Graphs of probabilities
//
//  To produce graphs that have smooth curves without too many symbols,
//  predictions are made every 1.25 years for the lines and every 5 years 
//  for the symbols. Lines are graphed with the connected command while 
//  symbols are graphed with the scatter command. While this complicates 
//  the code, it produces better graphs. Variables for symbols have S 
//  in their name; variables for lines have L.

global lindelta = 1.25
global symdelta = 5

qui est restore fullmodel

//  #2.1 Diabetes over age by race

mgen, at(white=1 age=(50($symdelta)90)) atmeans stub(ASprW) ///
    predlabel(White) replace // probabilities white

mgen, at(white=0 age=(50($symdelta)90)) atmeans stub(ASprN) ///
    predlabel(Nonwhite) replace // probabilities nonwhite

mgen, dydx(white) at(age=(50($symdelta)90)) atmeans stub(ASdc) ///
    predlabel(DC) replace // DCrace
label var ASdcll1 "95% confidence interval"
label var ASdcul1 "95% confidence interval"

mgen, at(white=1 age=(50($lindelta)90)) atmeans stub(ALprW) ///
    predlabel(White) replace // probabilities white

mgen, at(white=0 age=(50($lindelta)90)) atmeans stub(ALprN) ///
    predlabel(Nonwhite) replace // probabilities nonwhite

mgen, dydx(white) at(age=(50($lindelta)90)) atmeans stub(ALdc) ///
    predlabel(DC) replace // DCrace
label var ALdcll1 "95% confidence interval"
label var ALdcul1 "95% confidence interval"

//  Probabilties over age by group
//  Figure 7

twoway  ///
        (connected ALprWpr1  ALprWage, $LINwht) ///
        (connected ALprNpr1  ALprWage, $LINnon) ///
        (scatter ASprWpr1  ASprWage, $SYMwht) ///
        (scatter ASprNpr1  ASprWage, $SYMnon), ///
        ytitle(Pr(Diabetes)) xtitle(Age) ///
        xlabel(50(10)90) ylabel(0(.1).4, grid gmin gmax) ///
        yline(0, lcol(black) lwid(*.6)) ///
        legend(rows(1) order(4 3)) scale(1.2)
graph export `pgm'-agePR.emf, replace
graph export `pgm'-agePR.eps, replace

//  DC race - reverse direction of change for more effective plot
//  Figure 8

gen RALdcd_pr1  = -1 * ALdcd_pr1
gen RASdcd_pr1  = -1 * ASdcd_pr1
gen RALdcll1    = -1 * ALdcll1
gen RALdcul1    = -1 * ALdcul1
label var RALdcll1 "95% confidence interval"
label var RALdcul1 "95% confidence interval"

twoway ///
    (connected RALdcd_pr1        ALdcage,  $LINdc)  /// line
    (connected RALdcll1 RALdcul1 ALdcage,  $LINci)  /// ci
    (scatter   RASdcd_pr1        ASdcage,  $SYMdc), /// symbol
    ytitle("Pr(Diabetes | Nonwhite)" "- Pr(Diabetes | White)") ///
    xtitle(Age) xlabel(50(10)90) ylabel(0(.1).2, grid) ///
    yline(0, lcol(black) lwid(*.6)) ///
    legend(pos(6) ring(1) cols(1) order(3) symxsize(7)) scale(1.2)
graph export `pgm'-ageDCrace-reversed.emf, replace
graph export `pgm'-ageDCrace-reversed.eps, replace

//  #2.1.1
list ALprWage ALprWpr1 ALprNpr1 ALdcd_pr1 if ALprWage<., clean

//  #2.2 DC age by race at different ages
//  Results referred to in text

qui est restore fullmodel
* probability by race at different ages
mtable, at(white=(0 1) age=(50 60 65 75 80 90)) atmeans post
* change in probability from 50 to 60 if nonwhite
qui mlincom 2-1,            rowname(50->60:Nonwhite) clear add
* change in probability from 50 to 60 if white
qui mlincom 8-7,            rowname(50->60:White) add
* compare DC of age for whites and nonwhites
qui mlincom (2-1)-(8-7),    rowname(50->60:Difference) add
* other changes in ages
qui mlincom 4-3,            rowname(65->75:Nonwhite) add
qui mlincom 10-9,           rowname(65->75:White) add
qui mlincom (4-3)-(10-9),   rowname(65->75:Difference) add
qui mlincom 6-5,            rowname(80->90:Nonwhite) add
qui mlincom 12-11,          rowname(80->90:White) add
qui mlincom (6-5)-(12-11),  rowname(80->90:Difference) add
mlincom, twidth(25)

//  #2.3 Diabetes given age by race and level of physical activity
//  Generating variables for graphs

qui est restore fullmodel

* S==symbol L==line

* probabilities by age for nonwhites who are inactive
mgen, at(white=0 age=(50($symdelta)90) active=0) /// nonwhite inactive
    atmeans stub(ANSnoact) replace
label var ANSnoactpr1  "Nonwhite: inactive"
mgen, at(white=0 age=(50($lindelta)90) active=0) /// nonwhite inactive
    atmeans stub(ANLnoact) replace
label var ANLnoactpr1  "Nonwhite: inactive"

* probabilities by age for nonwhites who are active
mgen, at(white=0 age=(50($symdelta)90) active=1) /// nonwhite active
    atmeans stub(ANSact) replace
label var ANSactpr1  "Nonwhite: active"
mgen, at(white=0 age=(50($lindelta)90) active=1) /// nonwhite active
    atmeans stub(ANLact) replace
label var ANLactpr1  "Nonwhite: active"

* probabilities by age for whites who are inactive
mgen, at(white=1 age=(50($symdelta)90) active=0) /// white inactive
    atmeans stub(AWSnoact) replace
label var AWSnoactpr1  "White: inactive"
mgen, at(white=1 age=(50($lindelta)90) active=0) /// white inactive
    atmeans stub(AWLnoact) replace
label var AWLnoactpr1  "White: inactive"

* probabilities by age for whites who are active
mgen, at(white=1 age=(50($symdelta)90) active=1) /// white active
    atmeans stub(AWSact) replace
label var AWSactpr1  "White: active"
mgen, at(white=1 age=(50($lindelta)90) active=1) /// white active
    atmeans stub(AWLact) replace
label var AWLactpr1  "White: active"

//  #2.3a Race difference by age and activity

* race difference by age for those who are inactive
mgen, dydx(white) at(age=(50($symdelta)90) active=0) atmeans /// 
     stub(AWSnoactDC) stats(all) replace // DCwhite if inactive
label var AWSnoactDCd_pr1  "White - Nonwhite: inactive"
label var AWSnoactDCul1    "95% confidence interval"
label var AWSnoactDCll1    "95% confidence interval"

mgen, dydx(white) at(age=(50($lindelta)90) active=0) atmeans /// 
     stub(AWLnoactDC) stats(all) replace // DCwhite if inactive
label var AWLnoactDCd_pr1  "White - Nonwhite: inactive"
label var AWLnoactDCul1    "95% confidence interval"
label var AWLnoactDCll1    "95% confidence interval"

* race difference by age for those who are active
mgen, dydx(white) at(age=(50($symdelta)90) active=1) atmeans ///
     stub(AWShiactDC) stats(all) replace // DCwhite if active
label var AWShiactDCd_pr1  "White - Nonwhite: active"
label var AWShiactDCul1    "95%   confidence interval"
label var AWShiactDCll1    "95% confidence interval"

mgen, dydx(white) at(age=(50($lindelta)90) active=1) atmeans /// 
     stub(AWLhiactDC) stats(all) replace // DCwhite if active
label var AWLhiactDCd_pr1  "White - Nonwhite: active"
label var AWLhiactDCul1    "95%   confidence interval"
label var AWLhiactDCll1    "95% confidence interval"

//  Dashed line if race differences is not significant

gen AWLnoactDCsig = AWLnoactDCd_pr1 if AWLnoactDCpval1<=.05
label var AWLnoactDCsig   "Not active"
label var AWLnoactDCsig   ": significant"
label var AWLnoactDCd_pr1 ": not significant"

gen AWLhiactDCsig = AWLhiactDCd_pr1 if AWLhiactDCpval1<=.05
label var AWLhiactDCsig   "Active"
label var AWLhiactDCsig   ": significant"
label var AWLhiactDCd_pr1 ": not significant"

//  Probability by race and activity over age
//  Figure 9

twoway ///
    (connected AWLactpr1    AWLnoactage, $LINwhtA)  /// white active
    (connected AWLnoactpr1  AWLnoactage, $LINwhtI)  /// white inactive
    (connected ANLactpr1    AWLnoactage, $LINnonA)  /// nonwhite active
    (connected ANLnoactpr1  AWLnoactage, $LINnonI)  /// nonwhite inactive
    (scatter   AWSactpr1    AWSnoactage, $SYMwhtA)  /// white active
    (scatter   AWSnoactpr1  AWSnoactage, $SYMwhtI)  /// white inactive
    (scatter   ANSactpr1    AWSnoactage, $SYMnonA)  /// nonwhite active
    (scatter   ANSnoactpr1  AWSnoactage, $SYMnonI), /// nonwhite inactive
        xlabel(50(10)90) ylabel(0(.1).4, grid gmin gmax) ///
        ytitle(Pr(Diabetes)) xtitle(Age) ///
        yline(0, lcol(black) lwid(*.6)) ///
        legend(order(5 6 7 8) symxsize(6.7) pos(6) ///
               ring(1) cols(2) size(*.8)) scale(1.2)
graph export `pgm'-agePR-active.emf, replace
graph export `pgm'-agePR-active.eps, replace

//  DC race - reverse direction of race difference to improve graph
//  Figure 10

* lines
gen       RAWLhiactDCsig   = -1 * AWLhiactDCsig
label var RAWLhiactDCsig   "Active"
gen       RAWLhiactDCd_pr1 = -1 * AWLhiactDCd_pr1
label var RAWLhiactDCd_pr1 "Active: not significant"
gen       RAWLnoactDCsig   = -1 * AWLnoactDCsig
label var RAWLnoactDCsig   "Inactive"
gen       RAWLnoactDCd_pr1 = -1 * AWLnoactDCd_pr1
label var RAWLnoactDCd_pr1 "Inactive: not significant"
* symbols
gen       RAWShiactDCd_pr1 = -1 * AWShiactDCd_pr1
label var RAWShiactDCd_pr1 "Active"
gen       RAWSnoactDCd_pr1 = -1 * AWSnoactDCd_pr1
label var RAWSnoactDCd_pr1 "Inactive"

twoway ///
    (connected RAWLhiactDCsig   AWLnoactage, $LINdca ) /// active sig
    (connected RAWLhiactDCd_pr1 AWLnoactage, $LINdcans ) /// not sig
    (connected RAWLnoactDCsig   AWLnoactage, $LINdci ) /// inact sig
    (connected RAWLnoactDCd_pr1 AWLnoactage, $LINdcins ) ///not sig
    (scatter RAWShiactDCd_pr1 AWSnoactage, $SYMdca ) /// active
    (scatter RAWSnoactDCd_pr1 AWSnoactage, $SYMdci ) /// inactive
        , ///
        xtitle(Age) xlabel(50(10)90) ylabel(0(.1).2, grid gmin gmax) ///
        ytitle("Pr(Diabetes | Nonwhite)" "- Pr(Diabetes | White)") ///
        yline(0, lcol(black) lwid(*.6)) ///        
        legend(order(5 6) symxsize(6.7) pos(6) cols(2) size(*.8)) scale(1.2)
graph export `pgm'-ageDCrace-active-reversed.emf, replace
graph export `pgm'-ageDCrace-active-reversed.eps, replace

//  #2.3b DC activity by race

* DC of activity if nonwhite
mgen, dydx(active) at(age=(50($lindelta)90) white=0) atmeans /// nonwhite
     stub(AALnonwhDC) stats(all) replace
label var AALnonwhDCd_pr1 "Nonwhite"
label var AALnonwhDCul1   "95% confidence interval"
label var AALnonwhDCll1   "95% confidence interval"
mgen, dydx(active) at(age=(50($symdelta)90) white=0) atmeans /// nonwhite
     stub(AASnonwhDC) stats(all) replace
label var AASnonwhDCd_pr1 "Nonwhite"
label var AASnonwhDCul1   "95% confidence interval"
label var AASnonwhDCll1   "95% confidence interval"
* DC of activity if white
mgen, dydx(active) at(age=(50($lindelta)90) white=1) atmeans /// white
     stub(AALwhiteDC) stats(all) replace
label var AALwhiteDCd_pr1 "White"
label var AALwhiteDCul1   "95% confidence interval"
label var AALwhiteDCll1   "95% confidence interval"
mgen, dydx(active) at(age=(50($symdelta)90) white=1) atmeans /// white
     stub(AASwhiteDC) stats(all) replace
label var AASwhiteDCd_pr1 "White"
label var AASwhiteDCul1   "95% confidence interval"
label var AASwhiteDCll1   "95% confidence interval"

//  Dashed line if sig < .05

capture drop AALnonwhDCsig
gen AALnonwhDCsig = AALnonwhDCd_pr1 if AALnonwhDCpval1<=.05
label var AALnonwhDCsig   "Nonwhite"
gen AALwhiteDCsig = AALwhiteDCd_pr1 if AALwhiteDCpval1<=.05
label var AALwhiteDCsig   "White"

//  DC of activity by race
//  Figure 11

twoway  (connected AALnonwhDCsig   AALnonwhDCage, $LINdca) /// nonwhite sig
        (connected AALnonwhDCd_pr1 AALnonwhDCage, $LINdcans) /// not sig
        (connected AALwhiteDCsig   AALwhiteDCage, $LINdci) /// white sig
        (connected AALwhiteDCd_pr1 AALwhiteDCage, $LINdcins) /// not sig
        (scatter AASnonwhDCd_pr1 AASnonwhDCage, $SYMdca) /// nonwhite
        (scatter AASwhiteDCd_pr1 AASwhiteDCage, $SYMdci) /// white
        , ///
        xtitle(Age) xlabel(50(10)90) ylabel(-.1(.05)0, grid gmin gmax) ///
        ytitle("Pr(Diabetes | Active)" "- Pr(Diabetes | Inactive)") ///
        legend(order(5 6) symxsize(6.7) pos(6) ring(1) cols(2) size(*.8)) ///
        yline(0, lcol(black) lwid(*.6)) ///
        scale(1.2)
graph export `pgm'-ageDCactive-active.emf, replace
graph export `pgm'-ageDCactive-active.eps, replace

//  #2.3c 2nd differences: are DC of activity equal for whites and nonwhites?

est restore fullmodel
* DC of activity by race at different ages
mtable, dydx(active) at(age=(50(10)90) white=(0 1)) atmeans post

mlincom, clear
* race difference in DC of activity at age 50
qui mlincom  6-1, add rowname(DCactive age=50)
* race difference in DC of activity at age 60
qui mlincom  7-2, add rowname(DCactive age=60)
* race difference in DC of activity at age 70
qui mlincom  8-3, add rowname(DCactive age=70)
* race difference in DC of activity at age 80
qui mlincom  9-4, add rowname(DCactive age=80)
* race difference in DC of activity at age 90
mlincom 10-5, add rowname(DCactive age=90)

//  #2.3supplemental
//  Yearly effects of activity by race & tests of race differences in effects
//  Referred to in text -- commented out to speed up analyses

/* can comment out since it takes a long time */

di in red "Can comment out since it takes a long time"

mlincom, clear
forvalues age = 50(1)90 { // loop over ages
    qui est restore fullmodel
    * predictions of active white and inactive nonwhites
    qui mtable, ///
        at(age=`age' white=1 active=1) ///
        at(age=`age' white=1 active=0) ///
        at(age=`age' white=0 active=1) ///
        at(age=`age' white=0 active=0) ///
                post atmeans
    qui mlincom 2-1, add rowname(DCactive wht age=`age') // white DC active
    qui mlincom 4-3, add rowname(DCactive non age=`age') // non DC active
    qui mlincom (4-3)-(2-1), add rowname(2ndDIF age=`age') // diff
}
mlincom, title(active nonwhite - inactive white) dec(3) twidth(25)
/* can comment out since it takes a long time */

//  #2.4 Compare active nonwhite and inactive white

mlincom, clear
forvalues age = 50(10)90 { // loop over ages
    qui est restore fullmodel
    * predictions of active white and inactive nonwhites
    qui mtable, at(age=`age' active=0 white=1) ///
                at(age=`age' active=1 white=0) post atmeans
    qui mlincom 2-1, add rowname(DCrace age=`age') // DC race given age
}
mlincom, title(active nonwhite - inactive white) dec(3) twidth(25)

//  #2.4sup detailed comparison of active nonwhite and inactive white
//  Yearly effects of activity by race & tests of race differences in effects
//  Referred to in text

di in red "Can comment out since it takes a long time"

/* can comment out since it takes a long time */
mlincom, clear
forvalues age = 50(1)90 { // loop over ages
    qui est restore fullmodel
    * predictions of active white and inactive nonwhites
    qui mtable, at(age=`age' active=0 white=1) ///
                at(age=`age' active=1 white=0) post atmeans
    qui mlincom 2-1, add rowname(age=`age') // DC race given age
}
mlincom, title(active nonwhite - inactive white) dec(3)
/* can comment out since it takes a long time */

// =======================================
//  SECTION 3: Table for group differences

//  #3.1 prob(diabetes | female, obese, race)
//  Table 4 rows 1-2, columns 1-4

qui est restore fullmodel
* probability by race by female by obese at means
mtable, at(white=(0 1) female=(0 1) obese=(0 1)) atmeans stats(est pvalue)

//  #3.2 Race difference by gender and obesity: DCrace | female, obese
//  Table 4 row 3, columns 1-4

mtable, dydx(white) at(female=(0 1) obese=(0 1)) ///
    atmeans stats(est pvalue) post

//  #3.2a Compare race differences by gender and obesity
//  Table 4 row 3, columns 5-6 are from rows 3 and 4 below

qui mlincom 4-2, rowname(obese    men - obese    women)
qui mlincom 3-1, rowname(nonobese men - nonobese women) add
qui mlincom 4-3, rowname(women  obese - women nonobese) add
qui mlincom 2-1, rowname(men    obese - men   nonobese) add
mlincom, twidth(32) title(Second differences in DCobese and DCfemale)

//  #3.3 DC of obesity by race and gender: DCobese | white, female
//  Table 4 rows 1-2, columns 5-6

qui est restore fullmodel
mtable, dydx(obese) at(white=(0 1) female=(0 1)) ///
    atmeans stats(est pvalue) post

//  3.3a Additional tests: requires Stata 14.2+ due to bug in 14.1
//  Referred to in text

//  DC of obesity are equal across race and gender

test [1.obese]1bn._at = [1.obese]2._at = [1.obese]3._at = [1.obese]4._at

//  Compare DC of obesity for nonwhite men and white women

test [1.obese]1bn._at = [1.obese]4._at, accum

//  #3.4 Second and third differences to compare effects
//  Table 4 rows 1-3, column 7

qui mlincom 2-4, rowname(D2race|fem) clear
qui mlincom 1-3, rowname(D2race|mal) add
qui mlincom 4-3, rowname(D2gndr|wht) add
qui mlincom 2-1, rowname(D2gndr|non) add
mlincom (4-3)-(2-1), rowname(D3gndrXrace) add

// ==================================
//  SECTION 4: DC as summary measures

//  #4.1 ADC as summary measures
//  Table 5 Panel 1

qui est restore fullmodel

//  Compute DC of regressors by race to test if they are equal

est restore fullmodel
mtable, dydx(female) over(white) post brief dec(4)
mlincom (2),   rowname(ADC female: White)      twidth(25) add clear
mlincom (1),   rowname(ADC female: Nonwhite)   twidth(25) add
mlincom (2-1), rowname(ADC female: Difference) twidth(25) add

est restore fullmodel
mtable, ///
    at(age=gen(age)) at(age=gen(age+5)) over(white) post brief dec(4)
mlincom (4-2), rowname(ADC age+5: White)    add
mlincom (3-1), rowname(ADC age+5: Nonwhite) add
mlincom (4-2) - (3-1), ///
        rowname(ADC age+5: Difference) twidth(25) add

qui { // results are summarized below

est restore fullmodel
mtable, dydx(highschool) over(white) post brief dec(4)
mlincom (2),   rowname(ADC highschool: White)      twidth(25) add
mlincom (1),   rowname(ADC highschool: Nonwhite)   twidth(25) add
mlincom (2-1), rowname(ADC highschool: Difference) twidth(25) add

est restore fullmodel
mtable, dydx(married) over(white) post brief dec(4)
mlincom (2),   rowname(ADC married: White)      twidth(25) add
mlincom (1),   rowname(ADC married: Nonwhite)   twidth(25) add
mlincom (2-1), rowname(ADC married: Difference) twidth(25) add

est restore fullmodel
mtable, ///
        at(ihsincome=gen(ihsinc)) at(ihsincome=gen(ihsinc+1)) ///
        over(white) post brief dec(4)
mlincom (4-2), rowname(ADC ihsincome+1: White)      add
mlincom (3-1), rowname(ADC ihsincome+1: Nonwhite)   add
mlincom (4-2) - (3-1), ///
        rowname(ADC ihsincome+1: Difference) twidth(25) add

est restore fullmodel
mtable, ///
    at(age=gen(age)) at(age=gen(age+5)) over(white) post brief dec(4)
mlincom (4-2), rowname(ADC age+5: White)    add
mlincom (3-1), rowname(ADC age+5: Nonwhite) add
mlincom (4-2) - (3-1), ///
        rowname(ADC age+5: Difference) twidth(25) add

est restore fullmodel
mtable, dydx(active) over(white) post brief dec(4)
mlincom (2), rowname(ADC active: White)         twidth(25) add
mlincom (1), rowname(ADC active: Nonwhite)      twidth(25) add
mlincom (2-1), rowname(ADC active: Difference)  twidth(25) add

est restore fullmodel
mtable, dydx(obese) over(white) post brief dec(4)
mlincom (2),   rowname(ADC obese: White)        twidth(25) add
mlincom (1),   rowname(ADC obese: Nonwhite)     twidth(25) add
mlincom (2-1), rowname(ADC obese: Difference)   twidth(25) add

} // end quietly

mlincom, twidth(25) title(ADC by race)

//  #4.2 DCM as summary measures
//  Table 5 Panel 2

qui est restore fullmodel

svy: mean ihsincome // start and end for ihsincome
global incST = _b[ihsincome] // mean
global incEN = _b[ihsincome] + 1 // mean + 1

est restore fullmodel
mtable, dydx(female) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM female: White)       add clear
mlincom (1),   rowname(DCM female: Nonwhite)    add
mlincom (2-1), rowname(DCM female: Difference)  add

svy: mean age // compute start and end for age
global ageST = _b[age] // mean
global ageEN = _b[age] + 5 // mean + 5

est restore fullmodel
mtable, at((omeans) _all age=($ageST $ageEN) white=(0 1)) post dec(4)
mlincom (4-3),         rowname(DCM age+5: White)      add
mlincom (2-1),         rowname(DCM age+5: Nonwhite)   add
mlincom (4-3) - (2-1), rowname(DCM age+5: Difference) add

quietly {

est restore fullmodel
mtable, dydx(female) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM female: White)       add clear
mlincom (1),   rowname(DCM female: Nonwhite)    add
mlincom (2-1), rowname(DCM female: Difference)  add

est restore fullmodel
mtable, dydx(highschool) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM highschool: White)      add
mlincom (1),   rowname(DCM highschool: Nonwhite)   add
mlincom (2-1), rowname(DCM highschool: Difference) add

est restore fullmodel
mtable, dydx(married) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM married: White)      add
mlincom (1),   rowname(DCM married: Nonwhite)   add
mlincom (2-1), rowname(DCM married: Difference) add

est restore fullmodel
mtable, at((omeans) _all ihsincome=($incST $incEN) white=(0 1)) post dec(4)
mlincom (4-3), rowname(DCM ihsincome+1: White)      add
mlincom (2-1), rowname(DCM ihsincome+1: Nonwhite)   add
mlincom (4-3) - (2-1), ///
        rowname(DCM ihsincome+1: Difference) add

est restore fullmodel
mtable, at((omeans) _all age=($ageST $ageEN) white=(0 1)) post dec(4)
mlincom (4-3),         rowname(DCM age+5: White)      add
mlincom (2-1),         rowname(DCM age+5: Nonwhite)   add
mlincom (4-3) - (2-1), rowname(DCM age+5: Difference) add

est restore fullmodel
mtable, dydx(active) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM active: White)       add
mlincom (1),   rowname(DCM active: Nonwhite)    add
mlincom (2-1), rowname(DCM active: Difference)  add

est restore fullmodel
mtable, dydx(obese) post dec(4) at((omeans) _all white=(0 1))
mlincom (2),   rowname(DCM obese: White)      add
mlincom (1),   rowname(DCM obese: Nonwhite)   add
mlincom (2-1), rowname(DCM obese: Difference) add

} // end quietly

mlincom, twidth(25) title(DCM by race)
    
// =========================================================
//  SECTION 5: Allison type tests with location scale models

//  Models dropping female, highschool or married did not converge

// =======================
//  #5.1 Fully interactive
//  Table 6

//  In this model, innteraction should not be used to test if
//  coefficients are equal

global rhsfull ///
i.female i.highschool i.married c.ihsincome c.age##c.age##i.active i.obese

//  Full model results uses white#female and white#obese beta and pvalue

svy: logit diabetes i.white##($rhsfull), nolog
est store Mfull

predict Pfull1
label var Pfull1 "Predictions: full model"

//  DCM of obese and female by race
//  Referred to in text

mtable, dydx(obese) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

est restore Mfull
mtable, dydx(female) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

//  ADC of obese and female by race
//  Referred to in text

qui est restore Mfull
mtable, dydx(obese) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Mfull
mtable, dydx(female) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

// ============================================
//  #5.2a ihsincome coef constrained to be equal
//  Table 6

global rhsinc ///
i.female i.highschool i.married c.age##c.age##i.active i.obese

//  Results uses white#female and white#obese beta and pvalue
//  from Survey: Heteroskedastic Ordered Logistic Regression results

svy: oglm diabetes i.white $rhsfull ///
                   i.white#(${rhsinc}), het(i.white) log iterate(100)
est store Minc

//  Predictions
//  Referred to in text

predict Pinc0 Pinc1

//  DCM of obese by race
//  Referred to in text

mtable, dydx(obese) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

//  DCM of female by race
//  Referred to in text

qui est restore Minc
mtable, dydx(female) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

//  ADC of obese and female by race

qui est restore Minc
mtable, dydx(obese) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Minc
mtable, dydx(female) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

// ================================================================
//  #5.2b age coefs constrained to be equal (including interactions)
//  Table 6

global rhsage ///
i.female i.highschool i.married c.ihsincome i.obese

//  Results uses white#female and white#obese beta and pvalue
//  from Survey: Heteroskedastic Ordered Logistic Regression results

svy: oglm diabetes i.white $rhsfull ///
                   i.white#(${rhsage}), het(i.white) log iterate(100)
est store Mage

//  Predicted probabilities
//  Referred to in text

predict Page0 Page1

//  DCM of obese and female by race
//  Referred to in text

mtable, dydx(obese) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Mage
mtable, dydx(female) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(ageDCM:DCfemaleDCrace) add

//  ADC of obese and female by race
//  Referred to in text

qui est restore Mage
mtable, dydx(obese) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Mage
mtable, dydx(female) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

// ========================================
//  #5.2c obese coef constrained to be equal
//  Table 6

global rhsobe ///
i.female i.highschool i.married c.ihsincome c.age##c.age##i.active

svy: oglm diabetes i.white $rhsfull ///
                   i.white#(${rhsobe}), het(i.white) log iterate(100)
est store Mobe

//  Predicted probabilities
//  Referred to in text

predict Pobe0 Pobe1

//  DCM of obese and female by race
//  Referred to in text

mtable, dydx(obese) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Mobe
mtable, dydx(female) at(white=(0 1)) atmeans post
mlincom 1-2, rowname(Test if effects are equal)

//  ADC of obese and female by race
//  Referred to in text

qui est restore Mobe
mtable, dydx(obese) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

qui est restore Mobe
mtable, dydx(female) over(white) post
mlincom 1-2, rowname(Test if effects are equal)

//  #5.4 Compare predictions across models
//  Referred to in text

pwcorr P*1

log close
exit

DROPPED

* another way to compute DCMs
mchange $rhsvars, atmeans at(white=1) /// to verify results below
    amount(one delta) delta(5)
mchange $rhsvars, atmeans at(white=0) /// to verify results below
    amount(one delta) delta(5)

* another way to compute ADCs
mchange $rhsvars if white==1, /// to verify results below
    amount(one delta) delta(5) dec(3)
mchange $rhsvars if white==0, /// to verify results below
    amount(one delta) delta(5) dec(3)


/* DUPLICATE
twoway ///
    (connected RAWLhiactDCsig   AWLnoactage, $LINdca ) /// active sig
    (connected RAWLhiactDCd_pr1 AWLnoactage, $LINdcans ) /// not sig
    (connected RAWLnoactDCsig   AWLnoactage, $LINdci ) /// inact sig
    (connected RAWLnoactDCd_pr1 AWLnoactage, $LINdcins ) ///not sig
        , ///
        xtitle(Age) xlabel(50(10)90) ylabel(0(.1).2, grid gmin gmax) ///
        ytitle("Pr(Diabetes | Nonwhite)" "- Pr(Diabetes | White)") ///
        legend(order(1 3) symxsize(6.7) pos(6) cols(2) size(*.8)) scale(1.2)
graph export `pgm'-ageDCrace-active-reversed.emf, replace
graph export `pgm'-ageDCrace-active-reversed.eps, replace
*/
