capture log close
log using mco18-nrm-ordwarm-2018-03-27, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  MNLM of attitudes toward working women

local pgm mco18-nrm-ordwarm-2018-03-27
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  #1+ mnlm on warm ======================================================

use ordwarm4, clear
datasignature confirm

//  #21 descriptive statistics

tab1  warm
codebook warm yr89 male white age ed prst, compact

tab edcat

//  #22 base 1

mlogit warm i.yr89 i.male i.white age i.edcat prst, base(1) nolog
listcoef
est store base1

//  #24 wald tests of variables

//  edcat_set tests the 3 categories of edcat simultaneously; df=3x3=9

mlogtest, wald set(edcat_set=2.edcat 3.edcat 4.edcat)

//

* relative to 12 years (2)
qui mlogit warm i.yr89 i.male i.white age ib2.edcat prst, base(1) nolog
mlogtest 3.edcat,  wald // vs2
mlogtest 4.edcat,  wald // vs2
* relative to 13-15 years (3)
qui mlogit warm i.yr89 i.male i.white age ib3.edcat prst, base(1) nolog
mlogtest 4.edcat,  wald // vs3

//  #26 wald tests of combining categories

est restore base1
mlogtest, combine

//  #3+ mnlm predictions for interpretation  ==============================

//  #31 predicted probabilities

predict SDpr1 Dpr2 Apr3 SApr4
label var SDpr1 "Pr(SD1)"
label var Dpr2 "Pr(D2)"
label var Apr3 "Pr(A3)"
label var SApr4 "Pr(SA4)"
list warm SDpr1-SApr4 in 1/4, clean

local graphname "phat-dotplot"
dotplot SDpr1 Dpr2 Apr3 SApr4, ///
    ylab(0(.25)1, grid gmin gmax) mcolor(blue) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace
graph export `pgm'-`graphname'.png, width(1600) replace

//  #32 AME

mchange, amount(one sd)

local graphname "mchangeplot0-ame"
mchangeplot yr89 male, ///
    min(-.15) max(.15) gap(.05) /// ntics(7)
    mcolor(red orange green blue) /// hot vs cold
    title(Average marginal effect, position(11)) ///
    subtitle(1=SD 2=D 3=A 4=SA) ///
    aspect(.25) leftmargin(10) sig(.05) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "mchangeplot1-ame"
mchangeplot yr89 male white age prst, ///
    min(-.15) max(.15) gap(.05) /// ntics(7)
    mcolor(red orange green blue) /// hot vs cold
    title(Average marginal effect, position(11)) ///
    subtitle(1=SD 2=D 3=A 4=SA) ///
    aspect(.5) leftmargin(10) sig(.05) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "mchangeplot2-ame"
mchangeplot edcat, ///
    min(-.15) max(.15) gap(.05) /// ntics(7)
    mcolor(red orange green blue) /// hot vs cold
    title(Average marginal effect, position(11)) ///
    subtitle(1=SD 2=D 3=A 4=SA) ///
    aspect(.5) leftmargin(10) sig(.05) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #33 OR with significance levels with offset

local graphname "mlogitplot-sig-base4-offset1"
mlogitplot yr89 male white age prst, linep(.1) aspect(.7) linegapfactor(.4) ///
    base(4) min(-1.5) max(1.5) ntics(7) ///
    mcolor(red orange green blue) /// hot vs cold
    subtitle(1=SD 2=D 3=A 4=SA, pos(11)) ///
    offsetlist( 2  -2 -2  2  ///
                2  -2 -2  2  ///
                2  -2 -2  2  ///
                2  -2 -2  2  ///
                2  -2 -2  2  ///
               ) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "mlogitplot-sig-base4-offset2"
mlogitplot edcat, linep(.1) aspect(.7) linegapfactor(.4) ///
    base(4) min(-1.5) max(1.5) ntics(7) ///
    mcolor(red orange green blue) /// hot vs cold
    subtitle(1=SD 2=D 3=A 4=SA, pos(11)) ///
    offsetlist( 2  -2 -2  2  ///
                2  -2 -2  2  ///
                2  -2 -2  2  ///
               ) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #34 OR + DC plots with AME

local graphname "mlogitplot-ame-base4-offset"
mlogitplot yr89 male white age prst, ///
    linep(.1 .2 .3) lcolor(black) mshade aspect(.7) linegapfactor(.4) ///
    base(4) min(-1.5) max(1.5) ntics(7) ///
    mcolor(red orange green blue) /// hot vs cold
    offsetlist( 3  -3 -3  3  ///
                3  -3 -3  3  ///
                3  -3 -3  3  ///
                3  -3 -3  3  ///
                3  -3 -3  3  ///
               ) ///
    mchange msizefactor(1.1) ///
    subtitle(1=SD 2=D 3=A 4=SA, pos(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "mlogitplot-ame-base4-offset2"
mlogitplot edcat, linep(.1) aspect(.7) linegapfactor(.4) ///
    base(4) min(-1.5) max(1.5) ntics(7) ///
    mcolor(red orange green blue) /// hot vs cold
    subtitle(1=SD 2=D 3=A 4=SA, pos(11)) ///
    offsetlist( 2  -2 -2  2  ///
                2  -2 -2  2  ///
                2  -2 -2  2  ///
               ) ///
    mchange msizefactor(1.1) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #5+ mnlm iia test =====================================================

//  #51 testing iia

set seed 14293 // needed for Small Hsiao test
mlogtest, iia

set seed 201193 // needed for Small Hsiao test
mlogtest, iia

set seed 1102 // needed for Small Hsiao test
mlogtest, iia

log close
exit

