capture log close
log using mco18-nrm-partyid-2018-03-27, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  MNLM of party id

local pgm mco18-nrm-partyid-2018-03-27
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

global partycol "blue blue*.6 green*.8 red*.6 red"

//  #1+ mnlm on party

use partyid4, clear // load dataset

//  #11 descriptive statistics

tab1 party educ, miss
codebook party age income black female educ, compact
sum i.educ

//  create height variable for barchart

gen partyX = .
gen partyY = .
replace partyX = 1 in 1
replace partyX = 2 in 2
replace partyX = 3 in 3
replace partyX = 4 in 4
replace partyX = 5 in 5
replace partyY = 19.25 in 1
replace partyY = 30.90 in 2
replace partyY = 10.93 in 3
replace partyY = 26.70 in 4
replace partyY = 12.23 in 5

local graphname "bar-party"
twoway (bar partyY partyX, fcolor(green*.7) barwidth(0.8)), ///
    ytitle(Percent) yscale(range(0 33)) ylabel(#7) ///
    xtitle("") xlabel(1 "S: Strong Democrat" 2 "s: Democrat" ///
    3 "i: Independent" ///
    4 "r: Republican" 5 "R: St. Republican", alternate) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #12 MNLM

mlogit party age10 income10 i.black i.female i.educ
estimates store nrm

mlogtest, lr set(educ_set=2.educ 3.educ) // LR tests of variables
mlogtest, lrcomb // LR tests of combining categories

//  #13 odds ratios

listcoef

//  OR plot age and income with significance

local graphname "mlogitplot-sig"
mlogitplot age10 income10, base(3) amount(sd sd) ///
    linep(.1 .2 .3) lcolor(red) lshade ///
    symbols(D d i r R) linegapfactor(.6) ///
    offsetlist(2 2 0 -2 -2    0 2 -2 2 -2 ) ///
    titletop(Odds ratios scale relative to category I) ///
    titlebot(Logit coefficient scale relative to category I) ///
    mcol($partycol) min(-.3) max(.6) gap(.3) ///
    aspect(.4) varlabels ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #2+ marginal effects

mchange age10 income10, amount(sd)

//  #21 AME

//  DC plot

local graphname "mchangeplot-ame"
mchangeplot age10 income10, min(-.06) max(.06) gap(.02) ///
    amount(sd sd) symbols(D d i r R) /// SD change is plotted
    mcol($partycol) aspect(.3) sig(.05) ///
    title(Average marginal effects, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  OR plot with DC

local graphname "mlogitplot"
mlogitplot age10 income10, base(3) linep(.1 .2 .3) lcolor(red) lshade ///
    symbols(D d i r R) linegapfactor(.6) ///
    offsetlist(2 2 0 -2 -2    0 2 -2 2 -2 ) ///
    titletop(Odds ratios scale relative to category I) ///
    titlebot(Logit coefficient scale relative to category I) ///
    mcol($partycol) min(-.3) max(.6) gap(.3) ///
    aspect(.4) varlabels mchange ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #4+ probability plots

//  #41 generate predictions and make plots

mgen, atmeans at(age10=(2(.5)8.5)) stub(MNLMage) // predictions by age
mgen, atmeans at(income10=(0(1)10)) stub(MNLMinc) // predictions by inc

gen PLTincome = MNLMincincome10*10
label var PLTincome "Income in $1,000s"
gen PLTage = MNLMageage10*10
label var PLTage "Age"

//  plot options

global REGPnogap "plotregion(margin(zero) lcol(black) lwid(*.9))"

local yaxis_p ///
    "ytitle(Probability of party affiliation)"
local yaxis_p ///
    "`yaxis_p' ylab(0(.1).4, grid) ylin(0 .4, lcol(gs14))"
local yaxis_c ///
    "ytitle(Cumulative probability) ylab(0(.2)1, grid) ylin(0 1, lcol(gs14))"
local titleopt "position(11) size(medium)"

* line options for probabilities
local line5_opts "msym(O Oh dh sh s)"
local line5_opts "`line5_opts' lwid(*1.3 *1.3 *1.3 *1.3 *1.3)"
local line5_opts "`line5_opts' lpat(solid dash shortdash dash solid)"
local line5_opts "`line5_opts' mcol(red orange black green blue)"
local line5_opts "`line5_opts' lcol(red orange black green blue)"
local line5_opts "`line5_opts' mcol(red red*.8 black blue*.8 blue)"
local line5_opts "`line5_opts' lcol(red red*.8 black blue*.8 blue)"

* line options for cumulative probabilities
local line5_optsC "msymbol(O Oh dh sh s)"
local line5_optsC "`line5_optsC' lwid(*1.3 *1.3 *1.3 *1.3 *1.3)"
local line5_optsC "`line5_optsC' lpat(solid solid solid solid solid)"
local line5_optsC "`line5_optsC' mcol(red red*.8 black blue*.8 blue)"
local line5_optsC "`line5_optsC' lcol(red red*.8 black blue*.8 blue)"

local title "Multinomial logit model"
label var MNLMagepr1 "Strong Dem"
label var MNLMagepr2 "Democrat"
label var MNLMagepr3 "Independent"
label var MNLMagepr4 "Republican"
label var MNLMagepr5 "Strong Rep"
label var MNLMincpr1 "Strong Dem"
label var MNLMincpr2 "Democrat"
label var MNLMincpr3 "Independent"
label var MNLMincpr4 "Republican"
label var MNLMincpr5 "Strong Rep"
label var MNLMageCpr1 "Strong Dem"
label var MNLMageCpr2 "+ Democrat"
label var MNLMageCpr3 "+ Independent"
label var MNLMageCpr4 "+ Republican"
label var MNLMageCpr5 "+ Strong Rep"
label var MNLMincCpr1 "Strong Dem"
label var MNLMincCpr2 "+ Democrat"
label var MNLMincCpr3 "+ Independent"
label var MNLMincCpr4 "+ Republican"
label var MNLMincCpr5 "+ Strong Rep"

//  probability by age

local graphname "mnlm-ageProb"
graph twoway (connected MNLMagepr1 MNLMagepr2 MNLMagepr3 ///
    MNLMagepr4 MNLMagepr5 PLTage, `line5_opts'), ///
    title("`title'", `titleopt') `yaxis_p' `xaxis_age' ///
    $REGPnogap ///
    legend(rows(2)) caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  cumulative probability by age

local graphname "mnlm-ageCProb"
graph twoway (connected MNLMageCpr1 MNLMageCpr2 MNLMageCpr3 ///
    MNLMageCpr4 MNLMageCpr5 PLTage, `line5_optsC'), ///
    title("`title'", `titleopt') `yaxis_c' `xaxis_age' ///
    $REGPnogap ///
    legend(rows(2) colgap(small)) caption("`graphname' `tag'",size(*.5)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  probability by income

local graphname "mnlm-incProb"
graph twoway (connected MNLMincpr1 MNLMincpr2 MNLMincpr3 ///
    MNLMincpr4 MNLMincpr5 PLTincome, `line5_opts'), ///
    title("`title'", `titleopt') `yaxis_p' `xaxis_inc' ///
    $REGPnogap ///
    legend(rows(2)) caption("`graphname' `tag'",size(*.5)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  cumulative probability by income

local graphname "mnlm-incCProb"
graph twoway (connected MNLMincCpr1 MNLMincCpr2 MNLMincCpr3 ///
    MNLMincCpr4 MNLMincCpr5 PLTincome, `line5_optsC'), ///
    title("`title'", `titleopt') `yaxis_c' `xaxis_inc' ///
    $REGPnogap ///
    legend(rows(2) colgap(small)) caption("`graphname' `tag'",size(*.5)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #50 IIA tests

qui mlogit party age income i.black i.female i.educ, base(5) vsquish
mlogtest, hausman

set seed 124386
mlogtest, smhsiao

set seed 254331
mlogtest, smhsiao

set seed 86721129
mlogtest, smhsiao

//  #51 illustration of IIA

capture drop party15

mlogit party age, base(5) nolog vsquish

gen party15 = 1 if party==1
replace party15 = 0 if party==5
logit party15 age, nolog

log close
exit

